@@ -1,11 +1,14 @@
 const char *usage_msg[] = {
-	"  -a: append to alf file.",
+	"  -a: append to ALF file.",
 	"  -A: convert EOLs and tabs in all input files.",
 	"  -h: show this help message.",
-	"  -o: overwrite alf file if exists (do not create file~ backup).",
+	"  -o: overwrite ALF file if it exists (don't create file~ backup).",
+	"  -q: quiet.",
 	"  -td: use default LZ.COM timestamps.",
 	"  -tu: use UTC timestamps.",
 	"  -tz: use zero timestamps.",
+	"  -v: verbose (-vv: debug).",
 	"  -V: show version number.",
+	"  --: end of options (next arg is alf-file).",
 	(const char*)0
 };
