@@ -1,10 +1,11 @@
 #include <stdio.h>
 #include <string.h>
 #include "u816.h"
+#include "dupname.h"
 
 extern const char *self;
 
-void bad_atari_filename(const char *fname, const char *msg) {
+int safe_print_filename(const char *fname, FILE *fh) {
 	char fn[50] = "";
 	char xbuf[5];
 	int i;
@@ -20,7 +21,14 @@ void bad_atari_filename(const char *fname, const char *msg) {
 		}
 	}
 
-	fprintf(stderr, "%s: warning: bad Atari filename \"%s\": %s\n", self, fn, msg);
+	fputs(fn, fh);
+	return strlen(fn);
+}
+
+void bad_atari_filename(const char *fname, const char *msg) {
+	fprintf(stderr, "%s: warning: bad Atari filename \"", self);
+	safe_print_filename(fname, stderr);
+	fprintf(stderr, "\": %s\n", msg);
 }
 
 /* note to self: it's tempting to use isalpha(), isprint(), etc
@@ -64,6 +72,9 @@ void sanity_check_filename(const char *fname) {
 		bad_atari_filename(fname, "invalid characters.");
 	else if(uscore)
 		fprintf(stderr, "%s: filename has underscore, OK on Sparta/MyDOS, not Atari DOS 2.x\n", self);
+
+	if(is_dup_filename(fname)) {
+		fprintf(stderr, "%s: warning: duplicate Atari filename %s\n",
+				self, fname);
+	}
 }
-
-
